@@ -29,6 +29,15 @@ class MsgPush(object):
         if _dev: ic(self.keys)
 
     
+    def universal(self, title="test", desp="test"):
+        # Use all available push channels
+        # Notice: This method is not recommended and only supports text messages right now.
+        for channel in self.keys:
+            results = []
+            if(callable(getattr(self, channel))): results.append(getattr(self, channel)(title=title, desp=desp))
+        return results
+
+
 
     def serverchan(self, title="test", desp="test"):
         # https://sct.ftqq.com
@@ -58,6 +67,8 @@ class MsgPush(object):
         if group is not None: _paras["group"] = group
         if url is not None: _paras["url"] = url
         if icon is not None: _paras["icon"] = icon
+        ic(server)
+        ic("https://{}/{}/{}/{}".format(server, self.keys["bark"], title, desp))
         try:
             _req = requests.get("https://{}/{}/{}/{}".format(server, self.keys["bark"], title, desp), params=_paras, timeout=5)
         except Exception as e:
